package HT.fx;

import java.io.OutputStream;
import java.io.PrintStream;
import java.time.LocalDate;
import java.time.Period;

/**
 * @author joonatan, tuomas
 * @version 13.3.2024
 *
 */
public class Pelaaja {
    
    
    private int tunnusnro;
    private String nimi; 
    //private String syntymaaika; 
    private boolean auto;
    private String sahkoposti; 
    private LocalDate syntymaaika;
    
    private static int seuraavaNro = 1;
    
    /**
     * @param nimi pelaajan nimi
     * @param syntymaaika pelaajan syntymaaika
     * @param sahkoposti pelaajan sähköposti
     * @param auto onko pelaajalla auto
     */
    public Pelaaja(String nimi, LocalDate syntymaaika, String sahkoposti, boolean auto) {
        this.nimi = nimi;
        this.syntymaaika = syntymaaika;
        this.sahkoposti = sahkoposti; 
        this.auto = auto;
    }
    
    /**
     * Muodostaja tyhjän pelaajan luomiseen
     */
    public Pelaaja() {
        // TODO Auto-generated constructor stub
    }

    /**
     * Apumetodi, jolla saadaan täytettyä testiarvot jäsenelle.
     */
    public void vastaaAkuAnkka() {
        nimi = "Ankka Aku";
        syntymaaika = LocalDate.of(1951, 12, 5);  //5.12.1951";
        sahkoposti = "ankka.aku@luukku.fi";
        auto = true;   
    }
    
    /**
     * Tulostetaan henkilön tiedot
     * @param out tietovirta johon tulostetaan
     */
    public void tulosta(PrintStream out) {
        out.println(String.format("%03d", tunnusnro, 3) + "  " + nimi);
        out.println("     " + sahkoposti);
        out.println("     " + syntymaaika);
        if (auto) {out.println("     Pelaajalla on auto. ");}
    }
    
    /**
     * Tulostetaan henkilön tiedot
     * @param os tietovirta johon tulostetaan
     */
    public void tulosta(OutputStream os) {
        tulosta(new PrintStream(os));
    }
    
    /**
     * @return palauttaa pelaajan nimen
     */
    public String getNimi() {
        return nimi;
    }
    
    /**
     * @return palauttaa pelaajan iän
     */
    public int getIka() {
        return Period.between(syntymaaika, LocalDate.now()).getYears();  
        
    }
    
    /**
     * @return palauttaa pelaajan sähköpostin
     */
    public String getSahkoposti() {
        return sahkoposti;
    }
    
    /**
     * @return palauttaa tiedon onko pelaajalla auto, true = on auto
     */
    public boolean getAuto() {
        return auto;
    }

    
    /**
     * Antaa jäsenelle seuraavan rekisterinumeron.
     * @return jäsenen uusi tunnusNro
     * @example
     * <pre name="test">
     *   Pelaaja aku1 = new Pelaaja();
     *   aku1.getTunnusNro() === 0;
     *   aku1.rekisteroi();
     *   Pelaaja aku2 = new Pelaaja();
     *   aku2.rekisteroi();
     *   int n1 = aku1.getTunnusNro();
     *   int n2 = aku2.getTunnusNro();
     *   n1 === n2-1;
     * </pre>
     */
    public int rekisteroi() {
        tunnusnro = seuraavaNro;
        seuraavaNro++;
        return tunnusnro;
    }
    
    /**
     * Palauttaa jäsenen tunnusnumeron.
     * @return jäsenen tunnusnumero
     */
    public int getTunnusNro() {
        return tunnusnro;
    }
    
    



    
    /**
     * Testiohjelma jäsenelle.
     * @param args ei käytössä
     */
    public static void main(String args[]) {
        Pelaaja aku = new Pelaaja(), aku2 = new Pelaaja();
        aku.rekisteroi();
        aku2.rekisteroi();
        aku.tulosta(System.out);
        aku.vastaaAkuAnkka();
        aku.tulosta(System.out);

        aku2.vastaaAkuAnkka();
        aku2.tulosta(System.out);

        aku2.vastaaAkuAnkka();
        aku2.tulosta(System.out);
    }



}
